@@ -14,6 +14,7 @@ from suanpan.log import logger
 from suanpan.base import Context
 from suanpan.stream import stream
 from suanpan.arguments import suanpanTypes
+from suanpan.arguments.base import String
 
 
 class APP:
@@ -86,7 +87,7 @@ class APP:
         try:
             self.paramContext = self.loadParams(g)
             if self.afterInitFunc:
-                self.afterInitFunc(Context(args=self.paramContext))
+                self.afterInitFunc(Context(args=Context(**self.paramContext)))
         except Exception as e:
             tracebackInfo = traceback.format_exc()
             logger.error(
@@ -95,7 +96,7 @@ class APP:
             os._exit(0)
         if self.beforeExitFunc:
             try:
-                self.registerBeforeExitHooks(Context(args=self.paramContext))
+                self.registerBeforeExitHooks(Context(args=Context(**self.paramContext)))
             except Exception as e:
                 tracebackInfo = traceback.format_exc()
                 logger.error(
@@ -120,7 +121,7 @@ class APP:
         for key, value in configs.items():
             arguments.update({
                 key:
-                suanpanTypes.get(value["type"], "string")(key=key, alias=value["uuid"])
+                suanpanTypes.get(value["type"], String)(key=key, alias=value["uuid"])
             })
         return arguments
 
